@@ -21,8 +21,8 @@
 createStreamsCpu = function(n=prod(getOption('clrng.Nglobal'))){
   
   n = as.integer(n)
-  
-  if(!exists(".Random.seed.clrng", envir = .GlobalEnv)) {
+  pos <- 1
+  if(!exists(".Random.seed.clrng", envir = as.environment(pos))) {
     setBaseCreator()
   } 
   
@@ -31,18 +31,18 @@ createStreamsCpu = function(n=prod(getOption('clrng.Nglobal'))){
   streamsCpu<- matrix(0L, nrow=as.integer(n), ncol=12)
   
   currentCreator = CreateStreamsBackend(
-    .Random.seed.clrng,  
+    get(".Random.seed.clrng", envir = as.environment(pos)),  
     streamsR,
     streamsCpu,
     onGpu=FALSE,
     keepInitial=TRUE)
   # 
-  assign(".Random.seed.clrng", currentCreator, envir = .GlobalEnv)
+  assign(".Random.seed.clrng", currentCreator, envir = as.environment(pos))
   streamsCpu
   
 }    
 
-utils::globalVariables(".Random.seed.clrng")
+
 
 
 
